==> flwr_nightly-1.8.0.dev20240216-py3-none-any.whl: flwr/server/__init__.py <==
# Copyright 2020 Flower Labs GmbH. All Rights Reserved.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
# ==============================================================================
"""Flower server."""


from . import driver, strategy
from .app import run_driver_api as run_driver_api
from .app import run_fleet_api as run_fleet_api
from .app import run_superlink as run_superlink
from .app import start_server as start_server
from .client_manager import ClientManager as ClientManager
from .client_manager import SimpleClientManager as SimpleClientManager
from .compat import start_driver as start_driver
from .history import History as History
from .run_serverapp import run_server_app as run_server_app
from .server import Server as Server
from .server_config import ServerConfig as ServerConfig
from .serverapp import ServerApp as ServerApp

__all__ = [
    "ClientManager",
    "driver",
    "History",
    "run_driver_api",
    "run_fleet_api",
    "run_server_app",
    "run_superlink",
    "Server",
    "ServerApp",
    "ServerConfig",
    "SimpleClientManager",
    "start_driver",
    "start_server",
    "strategy",
]

==> flwr_nightly-1.9.0.dev20240513-py3-none-any.whl: flwr/server/__init__.py <==
# Copyright 2020 Flower Labs GmbH. All Rights Reserved.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
# ==============================================================================
"""Flower server."""


from . import strategy
from . import workflow as workflow
from .app import run_driver_api as run_driver_api
from .app import run_fleet_api as run_fleet_api
from .app import run_superlink as run_superlink
from .app import start_server as start_server
from .client_manager import ClientManager as ClientManager
from .client_manager import SimpleClientManager as SimpleClientManager
from .compat import LegacyContext as LegacyContext
from .driver import Driver as Driver
from .history import History as History
from .run_serverapp import run_server_app as run_server_app
from .server import Server as Server
from .server_app import ServerApp as ServerApp
from .server_config import ServerConfig as ServerConfig

__all__ = [
    "ClientManager",
    "Driver",
    "History",
    "LegacyContext",
    "run_driver_api",
    "run_fleet_api",
    "run_server_app",
    "run_superlink",
    "Server",
    "ServerApp",
    "ServerConfig",
    "SimpleClientManager",
    "start_server",
    "strategy",
    "workflow",
]
